<?php

class Shopware_Plugins_Frontend_EnderecoAMS_Bootstrap extends Shopware_Components_Plugin_Bootstrap
{

  public $cNamespaceLabel = 'EnderecoAMS'; 

  public $enable_log = true; 

  public function getVersion()
  {
    return "1.0.0";
  }

  public function getInfo()
  {
       return array(
        'version' => $this->getVersion(),
        'label' => 'Endereco AMS',
        'author' => 'Endereco UG',
        'copyright' => 'Copyright © 2018, Endereco UG',
        'description' => 'Adressvalidierung + Korrekturvorschläge für Webshops',
        'support' => 'support@endereco.de',
        'link' => 'https://www.endereco.de/'
      );
  }

  private function supportAttributes()
  {
    return $this->assertMinimumVersion('5.3.4');
  }

  public function getSnippet($snippet)
  { 
    if (is_array($snippet)) {
      return Shopware()->Snippets()->getNamespace('frontend/'.$this->cNamespaceLabel)->get($snippet['name'], $snippet['default']);
    } else {
      return $snippet;
    }
  }

  private $clearCache = array(
     'http'
  );


  public function getCapabilities()
  {
      return array(
          'install' => true,
          'enable' => true,
          'update' => true,
          'secureUninstall' => true
      );
  }

  public function install()
  {
    try {
      $this->installSnippets();
      $this->registerControllers(); 
      $this->CreateEvents();  
      $this->CreateForm();    

      return array('success' => true, 'invalidateCache' => $this->clearCache);

    } catch (Exception $exception) {
      $this->uninstall();
      throw new Exception($exception->getMessage());
    }
  }

  private function doUninstall($isSecureUninstall)
  {
     $this->unInstallSnippets();
     parent::uninstall();
     return $isSecureUninstall?true:array('success' => true,  'invalidateCache' => $this->clearCache);  
  }

  public function uninstall()
  {
     return $this->doUninstall(false);
  }

  public function secureUninstall()
  {
     return $this->doUninstall(true);
  }

  public function afterInit()
  {
     $this->registerNamespaces();  
  }

  public function registerControllers()
 {
    $this->registerController('Frontend', 'Enderecocontroller');
    $this->registerController('Frontend', 'Enderecocontroller2');
  }

  public function registerNamespaces()
  {
       $path = "Shopware\Plugins"."\\".$this->cNamespaceLabel;
       $this->Application()->Loader()->registerNamespace($path, $this->Path());
       $this->Application()->Loader()->registerNamespace($path.'\resources', $this->Path().'resources');
       $this->Application()->Loader()->registerNamespace($path.'\Controllers', $this->Path().'Controllers');
  }


  public function CreateEvents()
  {
      $this->subscribeEvent('Enlight_Controller_Action_PostDispatchSecure_Frontend','onPostDispatch');  
  }


  public function installSnippets()
  {
       $this->unInstallSnippets();
       $suf = [""];
       foreach ($suf as $s) {       
         $ini_path = $this->Path() . 'resources/snippets/'.$this->cNamespaceLabel.$s.'.ini';
         $ini_array = parse_ini_file($ini_path, true);
         if ( $ini_array && (count($ini_array)>0) ) {
             $ini_keys = array_keys($ini_array);
             if (count($ini_keys)==0) {
               $ini_keys = array('en_GB');
             }
             $locales = [];
             for ($i = 0; $i < count($ini_keys); $i++) {
                $alllocales = Shopware()->Db()->fetchAll("SELECT * FROM s_core_locales WHERE locale='".$ini_keys[$i]."'");
                if ($alllocales) {
                  foreach ($alllocales as $locale) {
                      $locales[]=array($locale["id"],$ini_keys[$i]);
                  } 
                }
             } 
             $shopsid=[];
             $shops = Shopware()->Db()->fetchAll("SELECT * FROM s_core_shops");
             if ($shops) {
               foreach ($shops as $shop) {
                 $shopsid[]=$shop["id"];
               } 
             }
             for ($i = 0; $i < count($shopsid); $i++) {
                for ($j = 0; $j < count($locales); $j++) {
                    while (list($snippet_name, $snippet_value) = each($ini_array[$locales[$j][1]])) {
                      $sqlQuery = "INSERT INTO s_core_snippets (namespace, shopID, localeID, name, value, created, updated) VALUES (?,?,?,?,?,now(),now())";
                      Shopware()->Db()->query($sqlQuery,['frontend/'.$this->cNamespaceLabel, $shopsid[$i], $locales[$j][0], $snippet_name, $snippet_value]); 
                    }
                }   
             } 
         }
       }
  }

  public function unInstallSnippets()
  {
      Shopware()->Db()->query("DELETE FROM s_core_snippets WHERE namespace='frontend/".$this->cNamespaceLabel."'");
  }

public function CreateForm()
{
  $form = $this->Form();

  $booleanArray = array(
    array(0, $this->getSnippet(['name' => 'ConfigNo','default' => 'No'])),
    array(1, $this->getSnippet(['name' => 'ConfigYes','default' => 'Yes']))
  ); 
  
  $elogArray = array(
    array(0, 'OFF'),
    array(1, 'ERROR'),
    array(2, 'WARN'),
    array(3, 'DEBUG'),
    array(4, 'INFO'),
    array(5, 'TIME'),
  );

  $form->setElement('text', 'EnderecoAMS_Mandant',
    array(
      'label'     => $this->getSnippet(['name' => 'ConfigMandator','default' => 'Mandator']),
      'required'  => true,
      'description'  => $this->getSnippet(['name' => 'ConfigMandatorHelp','default' => 'Mandator']), 
    )
  );
   $form->setElement('text', 'EnderecoAMS_Benutzername',
    array(
      'label'     => $this->getSnippet(['name' => 'ConfigLogin','default' => 'User login name']),
      'required'  => true,
      'description'  => $this->getSnippet(['name' => 'ConfigLoginHelp','default' => 'User login name']), 
    )
  );
    $form->setElement('text', 'EnderecoAMS_Passwort',
    array(
      'label'     => $this->getSnippet(['name' => 'ConfigPassword','default' => 'User password']),
      'required'  => true,
      'description'  => $this->getSnippet(['name' => 'ConfigPasswordHelp','default' => 'User password']), 
    )
  );
 $form->setElement('select', 'EnderecoAMS_check',
    array(
      'label'     => $this->getSnippet(['name' => 'ConfigCheck','default' => 'Always perform address-check?']),
      'scope'     => \Shopware\Models\Config\Element::SCOPE_SHOP,
      'required'  => false,
      'store'     => $booleanArray,
      'value'     => 1,
      'description'  => $this->getSnippet(['name' => 'ConfigCheckHelp','default' => 'Always perform address-check?']), 
    )
  ); 
  $form->setElement('select', 'EnderecoAMS_ShowAllCityNames',
    array(
      'label'     => $this->getSnippet(['name' => 'ConfigShowAll','default' => 'Provide all additions']),
      'scope'     => \Shopware\Models\Config\Element::SCOPE_SHOP,
      'required'  => false,
      'store'     => $booleanArray,
      'value'     => 1,
      'description'  => $this->getSnippet(['name' => 'ConfigShowAllHelp','default' => 'Provide all City and City name additions per zipcode']), 
    )
  );
  $form->setElement('select', 'EnderecoAMS_loglevel',
    array(
      'label'     => $this->getSnippet(['name' => 'ConfigLogLevel','default' => 'Log level']),
      'scope'     => \Shopware\Models\Config\Element::SCOPE_SHOP,
      'required'  => false,
      'store'     => $elogArray,
      'value'     => 0,
      'description'  => $this->getSnippet(['name' => 'ConfigLogLevelHelp','default' => 'Log level']), 
    )
  );
  $form->setElement('text', 'EnderecoAMS_Countries',
    array(
      'label'     => $this->getSnippet(['name' => 'ConfigCountries','default' => 'Countries allowed']),
      'required'  => false,
      'value'     => 'german,deutsch',
      'description'  => $this->getSnippet(['name' => 'ConfigCountriesHelp','default' => 'Template for names of allowed countries']), 
    )
  );
  $form->setElement('text', 'EnderecoAMS_timeout',
    array(
      'label'     => $this->getSnippet(['name' => 'ConfigTimeout','default' => 'Request timeout']),
      'required'  => false,
      'value'     => '500',
      'description'  => $this->getSnippet(['name' => 'ConfigTimeoutHelp','default' => 'Request timeout']), 
    )
  );

}

public function onPostDispatch(\Enlight_Controller_ActionEventArgs $args){    

    $controller = $args->get('subject');
    $request = $controller->Request();
    
    $action_name = $request->getActionName();
    $name = $request->getControllerName();

    if (
       (($name == 'address') && (($action_name == 'edit') || ($action_name == 'create'))) 
       || (($name == 'register') && ($action_name == 'saveRegister'))
    ) {
      $attrs = $request->getAttributes();
      if (is_array($attrs) && $attrs["isValidated"]) {
        $this->onAddressSuccessfull(["controller" => $name, "action" => $action_name]);
      }
    }
    if (($name == 'address') && ($action_name == 'ajaxSave')) {
      $response = $controller->Response();
      if ($response) {
        $attrs = json_decode($controller->Response()->getBody(), true);
        if (is_array($attrs) && ($attrs["success"] === true)) {
          $this->onAddressSuccessfull(["controller" => $name, "action" => $action_name]);
        } 
      }
    }    
    
    if (in_array($name,  ['account', 'checkout', 'address', 'register'])) {

        $view = $controller->View();
        $view->addTemplateDir($this->Path() . 'Views/');

        $timeout = intval($this->Config()->get('EnderecoAMS_timeout',500));
        if (!$timeout || ($timeout < 10)) {
          $timeout = 10;
        } 
        $view->assign('nEnderecoTimeout', $timeout);

        $view->assign('bCheckEveryTime', $this->Config()->get('EnderecoAMS_check',1));
        $view->assign('nEnderecoLogLevel', $this->Config()->get('EnderecoAMS_loglevel',0));        
        $view->assign('sCountriesAllowed', $this->getCountriesAllowed($this->Config()->get('EnderecoAMS_Countries','')));

        $plugin_path = str_replace("\\", '/', $this->Path()); 
        $p = stripos($plugin_path, "/engine/Shopware/Plugins");
        if (($p) && ($p>0)) {
           $view->assign('ams_plugin_path', substr($plugin_path, $p));
        } 
        $host = rtrim(Shopware()->Shop()->getHost(), '/');      
        if ($host != 'localhost') {
          if (!stripos($host, 'http://') && !stripos($host, 'https://')) {
            $host = 'http://'. $host;
          } 
        }
        $view->assign('server_host', $host.'/'); 
        $view->assign('controller_name', $name);
        $view->assign('controller_action', $action_name);
        $view->assign('controller_action_common', $action_name);               

        $need_check = false;
        
        if ($name == 'register')  {
            if ($action_name == 'index')  {             
               $view->assign('endereco_mode_double', true); 
               $need_check = true;
            }  
        } else if ($name == 'address')  {
            if (($action_name == 'edit') || ($action_name == 'create'))  {  
                $need_check = true;
                $view->assign('controller_action_common', 'common');
            } else if ($action_name == 'ajaxEditor') {
                $view->extendsTemplate('frontend/endereco_ams_'.$name.'_'.$action_name.'.tpl');
            }
        } else if ((($name == 'checkout') && ($action_name == 'confirm')) || (($name == 'account') && ($action_name == 'index')))  {
            $view->assign('endereco_modal_mode', true);
            $view->extendsTemplate('frontend/common/styles.tpl');
            $view->extendsTemplate('frontend/common/scripts.tpl');
        }  
        if ($need_check) {           
            $view->extendsTemplate('frontend/endereco_ams_'.$name.'_'.$action_name.'.tpl');            
            $view->extendsTemplate('frontend/common/styles.tpl');
            $view->extendsTemplate('frontend/common/scripts.tpl');
        }
    }
}

private function onAddressSuccessfull($data) {
   //$this->writeToLog($data);
}

private function getCountriesAllowed ($src) {
     $res = '';
     $data = explode(',',$src);
     foreach ($data as $s) {
        if (trim($s)) {
          if ($res) { $res .= ','; }
          $res .= '"'.trim($s).'"';
        }
     }
     return $res;
}

public function writeToLog($txt, $cpt = '') { 
    if ($this->enable_log) {
       if ($cpt) {
          error_log(' ------------ '.$cpt.' ------------ ');
       }
       ob_start();
       print_r($txt);
       $contents = ob_get_contents();
       ob_end_clean();
       error_log($contents);
    }
} 

}